/****************************************************************************
** Meta object code from reading C++ file 'filter.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../kjournald-26.08.0/org/kde/kjournald/filter.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'filter.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN6FilterE_t {};
} // unnamed namespace

template <> constexpr inline auto Filter::qt_create_metaobjectdata<qt_meta_tag_ZN6FilterE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Filter",
        "QML.Element",
        "anonymous",
        "priority",
        "boots",
        "userUnits",
        "systemUnits",
        "exes",
        "kernel"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'priority'
        QtMocHelpers::PropertyData<int>(3, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::Resettable),
        // property 'boots'
        QtMocHelpers::PropertyData<QStringList>(4, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'userUnits'
        QtMocHelpers::PropertyData<QStringList>(5, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'systemUnits'
        QtMocHelpers::PropertyData<QStringList>(6, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'exes'
        QtMocHelpers::PropertyData<QStringList>(7, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'kernel'
        QtMocHelpers::PropertyData<bool>(8, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<Filter, void>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject Filter::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6FilterE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6FilterE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6FilterE_t>.metaTypes,
    nullptr
} };

void Filter::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = reinterpret_cast<Filter *>(_o);
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<int*>(_v) = _t->priorityFilterInt(); break;
        case 1: *reinterpret_cast<QStringList*>(_v) = _t->bootFilter(); break;
        case 2: *reinterpret_cast<QStringList*>(_v) = _t->systemdUserUnitFilter(); break;
        case 3: *reinterpret_cast<QStringList*>(_v) = _t->systemdSystemUnitFilter(); break;
        case 4: *reinterpret_cast<QStringList*>(_v) = _t->exeFilter(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->areKernelMessagesEnabled(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setPriorityFilter(*reinterpret_cast<int*>(_v)); break;
        case 1: _t->setBootFilter(*reinterpret_cast<QStringList*>(_v)); break;
        case 2: _t->setSystemdUserUnitFilter(*reinterpret_cast<QStringList*>(_v)); break;
        case 3: _t->setSystemdSystemUnitFilter(*reinterpret_cast<QStringList*>(_v)); break;
        case 4: _t->setExeFilter(*reinterpret_cast<QStringList*>(_v)); break;
        case 5: _t->setKernelMessagesEnabled(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
    if (_c == QMetaObject::ResetProperty) {
        switch (_id) {
        case 0: _t->resetPriorityFilter(); break;
        default: break;
        }
    }
}
QT_WARNING_POP
