/****************************************************************************
** Meta object code from reading C++ file 'logentry.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../kjournald-26.08.0/org/kde/kjournald/logentry.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'logentry.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN8LogEntryE_t {};
} // unnamed namespace

template <> constexpr inline auto LogEntry::qt_create_metaobjectdata<qt_meta_tag_ZN8LogEntryE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "LogEntry",
        "QML.Element",
        "entry",
        "matches",
        "",
        "needle",
        "caseSensitive",
        "id",
        "message",
        "date",
        "monotonicTimestamp",
        "priority",
        "bootId",
        "unit",
        "exe",
        "cursor"
    };

    QtMocHelpers::UintData qt_methods {
        // Method 'matches'
        QtMocHelpers::MethodData<bool(const QString &, bool) const>(3, 4, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 5 }, { QMetaType::Bool, 6 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'id'
        QtMocHelpers::PropertyData<QString>(7, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'message'
        QtMocHelpers::PropertyData<QString>(8, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'date'
        QtMocHelpers::PropertyData<QDateTime>(9, QMetaType::QDateTime, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'monotonicTimestamp'
        QtMocHelpers::PropertyData<quint64>(10, QMetaType::ULongLong, QMC::DefaultPropertyFlags),
        // property 'priority'
        QtMocHelpers::PropertyData<int>(11, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'bootId'
        QtMocHelpers::PropertyData<QString>(12, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'unit'
        QtMocHelpers::PropertyData<QString>(13, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'exe'
        QtMocHelpers::PropertyData<QString>(14, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'cursor'
        QtMocHelpers::PropertyData<QString>(15, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<LogEntry, void>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject LogEntry::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8LogEntryE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8LogEntryE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN8LogEntryE_t>.metaTypes,
    nullptr
} };

void LogEntry::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = reinterpret_cast<LogEntry *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { bool _r = _t->matches((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->id(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->message(); break;
        case 2: *reinterpret_cast<QDateTime*>(_v) = _t->date(); break;
        case 3: *reinterpret_cast<quint64*>(_v) = _t->monotonicTimestamp(); break;
        case 4: *reinterpret_cast<int*>(_v) = _t->priority(); break;
        case 5: *reinterpret_cast<QString*>(_v) = _t->bootId(); break;
        case 6: *reinterpret_cast<QString*>(_v) = _t->unit(); break;
        case 7: *reinterpret_cast<QString*>(_v) = _t->exe(); break;
        case 8: *reinterpret_cast<QString*>(_v) = _t->cursor(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setId(*reinterpret_cast<QString*>(_v)); break;
        case 1: _t->setMessage(*reinterpret_cast<QString*>(_v)); break;
        case 2: _t->setDate(*reinterpret_cast<QDateTime*>(_v)); break;
        case 4: _t->setPriority(*reinterpret_cast<int*>(_v)); break;
        case 5: _t->setBootId(*reinterpret_cast<QString*>(_v)); break;
        case 6: _t->setUnit(*reinterpret_cast<QString*>(_v)); break;
        case 7: _t->setExe(*reinterpret_cast<QString*>(_v)); break;
        case 8: _t->setCursor(*reinterpret_cast<QString*>(_v)); break;
        default: break;
        }
    }
}
QT_WARNING_POP
