/****************************************************************************
** Meta object code from reading C++ file 'journaldviewmodel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../kjournald-26.08.0/org/kde/kjournald/journaldviewmodel.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'journaldviewmodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN17JournaldViewModelE_t {};
} // unnamed namespace

template <> constexpr inline auto JournaldViewModel::qt_create_metaobjectdata<qt_meta_tag_ZN17JournaldViewModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "JournaldViewModel",
        "QML.Element",
        "auto",
        "filterChanged",
        "",
        "journalProviderChanged",
        "availableChanged",
        "groupTemplatedSystemdUnitsChanged",
        "fetchMoreLogEntries",
        "std::pair<int,int>",
        "datetime",
        "indexRow",
        "search",
        "searchString",
        "startRow",
        "caseSensitive",
        "JournaldViewModel::Direction",
        "direction",
        "seekHead",
        "seekTail",
        "closestIndexForData",
        "journalProvider",
        "IJournalProvider*",
        "available",
        "filter",
        "Filter",
        "enableSystemdUnitTemplateGrouping",
        "Roles",
        "MESSAGE",
        "MESSAGE_ID",
        "ENTRY",
        "DATE",
        "DATETIME",
        "MONOTONIC_TIMESTAMP",
        "PRIORITY",
        "SYSTEMD_UNIT",
        "SYSTEMD_UNIT_CHANGED_SUBSTRING",
        "BOOT_ID",
        "SYSTEMD_UNIT_COLOR_BACKGROUND",
        "SYSTEMD_UNIT_COLOR_FOREGROUND",
        "EXE_COLOR_BACKGROUND",
        "EXE_COLOR_FOREGROUND",
        "EXE",
        "EXE_CHANGED_SUBSTRING",
        "CURSOR",
        "Direction",
        "FORWARD",
        "BACKWARD"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'filterChanged'
        QtMocHelpers::SignalData<void()>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'journalProviderChanged'
        QtMocHelpers::SignalData<void()>(5, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'availableChanged'
        QtMocHelpers::SignalData<void()>(6, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'groupTemplatedSystemdUnitsChanged'
        QtMocHelpers::SignalData<void()>(7, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'fetchMoreLogEntries'
        QtMocHelpers::SlotData<std::pair<int,int>()>(8, 4, QMC::AccessPrivate, 0x80000000 | 9),
        // Method 'datetime'
        QtMocHelpers::MethodData<QDateTime(int) const>(10, 4, QMC::AccessPublic, QMetaType::QDateTime, {{
            { QMetaType::Int, 11 },
        }}),
        // Method 'search'
        QtMocHelpers::MethodData<int(const QString &, int, bool, JournaldViewModel::Direction)>(12, 4, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::QString, 13 }, { QMetaType::Int, 14 }, { QMetaType::Bool, 15 }, { 0x80000000 | 16, 17 },
        }}),
        // Method 'search'
        QtMocHelpers::MethodData<int(const QString &, int, bool)>(12, 4, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Int, {{
            { QMetaType::QString, 13 }, { QMetaType::Int, 14 }, { QMetaType::Bool, 15 },
        }}),
        // Method 'seekHead'
        QtMocHelpers::MethodData<void()>(18, 4, QMC::AccessPublic, QMetaType::Void),
        // Method 'seekTail'
        QtMocHelpers::MethodData<void()>(19, 4, QMC::AccessPublic, QMetaType::Void),
        // Method 'closestIndexForData'
        QtMocHelpers::MethodData<int(const QDateTime &)>(20, 4, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::QDateTime, 10 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'journalProvider'
        QtMocHelpers::PropertyData<IJournalProvider*>(21, 0x80000000 | 22, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 1),
        // property 'available'
        QtMocHelpers::PropertyData<bool>(23, QMetaType::Bool, QMC::DefaultPropertyFlags, 2),
        // property 'filter'
        QtMocHelpers::PropertyData<Filter>(24, 0x80000000 | 25, QMC::DefaultPropertyFlags | QMC::Writable | QMC::Resettable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
        // property 'enableSystemdUnitTemplateGrouping'
        QtMocHelpers::PropertyData<bool>(26, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::Final, 3),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Roles'
        QtMocHelpers::EnumData<enum Roles>(27, 27, QMC::EnumFlags{}).add({
            {   28, Roles::MESSAGE },
            {   29, Roles::MESSAGE_ID },
            {   30, Roles::ENTRY },
            {   31, Roles::DATE },
            {   32, Roles::DATETIME },
            {   33, Roles::MONOTONIC_TIMESTAMP },
            {   34, Roles::PRIORITY },
            {   35, Roles::SYSTEMD_UNIT },
            {   36, Roles::SYSTEMD_UNIT_CHANGED_SUBSTRING },
            {   37, Roles::BOOT_ID },
            {   38, Roles::SYSTEMD_UNIT_COLOR_BACKGROUND },
            {   39, Roles::SYSTEMD_UNIT_COLOR_FOREGROUND },
            {   40, Roles::EXE_COLOR_BACKGROUND },
            {   41, Roles::EXE_COLOR_FOREGROUND },
            {   42, Roles::EXE },
            {   43, Roles::EXE_CHANGED_SUBSTRING },
            {   44, Roles::CURSOR },
        }),
        // enum 'Direction'
        QtMocHelpers::EnumData<enum Direction>(45, 45, QMC::EnumFlags{}).add({
            {   46, Direction::FORWARD },
            {   47, Direction::BACKWARD },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<JournaldViewModel, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject JournaldViewModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QAbstractItemModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17JournaldViewModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17JournaldViewModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN17JournaldViewModelE_t>.metaTypes,
    nullptr
} };

void JournaldViewModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<JournaldViewModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->filterChanged(); break;
        case 1: _t->journalProviderChanged(); break;
        case 2: _t->availableChanged(); break;
        case 3: _t->groupTemplatedSystemdUnitsChanged(); break;
        case 4: { std::pair<int,int> _r = _t->fetchMoreLogEntries();
            if (_a[0]) *reinterpret_cast<std::pair<int,int>*>(_a[0]) = std::move(_r); }  break;
        case 5: { QDateTime _r = _t->datetime((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDateTime*>(_a[0]) = std::move(_r); }  break;
        case 6: { int _r = _t->search((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<JournaldViewModel::Direction>>(_a[4])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 7: { int _r = _t->search((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 8: _t->seekHead(); break;
        case 9: _t->seekTail(); break;
        case 10: { int _r = _t->closestIndexForData((*reinterpret_cast<std::add_pointer_t<QDateTime>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (JournaldViewModel::*)()>(_a, &JournaldViewModel::filterChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (JournaldViewModel::*)()>(_a, &JournaldViewModel::journalProviderChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (JournaldViewModel::*)()>(_a, &JournaldViewModel::availableChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (JournaldViewModel::*)()>(_a, &JournaldViewModel::groupTemplatedSystemdUnitsChanged, 3))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< IJournalProvider* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<IJournalProvider**>(_v) = _t->journalProvider(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->isAvailable(); break;
        case 2: *reinterpret_cast<Filter*>(_v) = _t->filter(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->groupTemplatedSystemdUnits(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setJournalProvider(*reinterpret_cast<IJournalProvider**>(_v)); break;
        case 2: _t->setFilter(*reinterpret_cast<Filter*>(_v)); break;
        case 3: _t->setGroupTemplatedSystemdUnits(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
    if (_c == QMetaObject::ResetProperty) {
        switch (_id) {
        case 2: _t->resetFilter(); break;
        default: break;
        }
    }
}

const QMetaObject *JournaldViewModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *JournaldViewModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17JournaldViewModelE_t>.strings))
        return static_cast<void*>(this);
    return QAbstractItemModel::qt_metacast(_clname);
}

int JournaldViewModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAbstractItemModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 11)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 11;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    return _id;
}

// SIGNAL 0
void JournaldViewModel::filterChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void JournaldViewModel::journalProviderChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void JournaldViewModel::availableChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void JournaldViewModel::groupTemplatedSystemdUnitsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}
QT_WARNING_POP
