/****************************************************************************
** Meta object code from reading C++ file 'journalduniquequerymodel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../kjournald-26.08.0/org/kde/kjournald/journalduniquequerymodel.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'journalduniquequerymodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN24JournaldUniqueQueryModelE_t {};
} // unnamed namespace

template <> constexpr inline auto JournaldUniqueQueryModel::qt_create_metaobjectdata<qt_meta_tag_ZN24JournaldUniqueQueryModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "JournaldUniqueQueryModel",
        "QML.Element",
        "auto",
        "setData",
        "",
        "QModelIndex",
        "index",
        "QVariant",
        "value",
        "role",
        "journalPath",
        "field",
        "Roles",
        "FIELD",
        "SELECTED"
    };

    QtMocHelpers::UintData qt_methods {
        // Method 'setData'
        QtMocHelpers::MethodData<bool(const QModelIndex &, const QVariant &, int)>(3, 4, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 5, 6 }, { 0x80000000 | 7, 8 }, { QMetaType::Int, 9 },
        }}),
        // Method 'setData'
        QtMocHelpers::MethodData<bool(const QModelIndex &, const QVariant &)>(3, 4, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Bool, {{
            { 0x80000000 | 5, 6 }, { 0x80000000 | 7, 8 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'journalPath'
        QtMocHelpers::PropertyData<QString>(10, QMetaType::QString, QMC::Writable | QMC::Designable | QMC::Scriptable | QMC::Stored | QMC::Resettable),
        // property 'field'
        QtMocHelpers::PropertyData<QString>(11, QMetaType::QString, QMC::Writable | QMC::Designable | QMC::Scriptable | QMC::Stored),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Roles'
        QtMocHelpers::EnumData<enum Roles>(12, 12, QMC::EnumFlags{}).add({
            {   13, Roles::FIELD },
            {   14, Roles::SELECTED },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<JournaldUniqueQueryModel, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject JournaldUniqueQueryModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QAbstractItemModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24JournaldUniqueQueryModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24JournaldUniqueQueryModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN24JournaldUniqueQueryModelE_t>.metaTypes,
    nullptr
} };

void JournaldUniqueQueryModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<JournaldUniqueQueryModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { bool _r = _t->setData((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 1: { bool _r = _t->setData((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setJournaldPath(*reinterpret_cast<QString*>(_v)); break;
        case 1: _t->setFieldString(*reinterpret_cast<QString*>(_v)); break;
        default: break;
        }
    }
    if (_c == QMetaObject::ResetProperty) {
        switch (_id) {
        case 0: _t->setSystemJournal(); break;
        default: break;
        }
    }
}

const QMetaObject *JournaldUniqueQueryModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *JournaldUniqueQueryModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24JournaldUniqueQueryModelE_t>.strings))
        return static_cast<void*>(this);
    return QAbstractItemModel::qt_metacast(_clname);
}

int JournaldUniqueQueryModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAbstractItemModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 2;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    return _id;
}
QT_WARNING_POP
