/****************************************************************************
** Meta object code from reading C++ file 'browserapplication.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../kjournald-26.08.0/org/kde/kjournaldbrowser/browserapplication.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'browserapplication.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN18BrowserApplicationE_t {};
} // unnamed namespace

template <> constexpr inline auto BrowserApplication::qt_create_metaobjectdata<qt_meta_tag_ZN18BrowserApplicationE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "BrowserApplication",
        "QML.Element",
        "auto",
        "QML.Singleton",
        "true",
        "timeDisplayChanged",
        "",
        "BrowserApplication::TimeDisplay",
        "display",
        "filterCriteriumChanged",
        "BrowserApplication::FilterCriterium",
        "criterium",
        "viewModeChanged",
        "BrowserApplication::ViewMode",
        "mode",
        "logViewModeChanged",
        "BrowserApplication::LogViewMode",
        "serviceGroupingChanged",
        "BrowserApplication::ServiceGrouping",
        "logPriorityChanged",
        "priority",
        "timeDisplay",
        "filterCriterium",
        "viewMode",
        "logViewMode",
        "serviceGrouping",
        "logPriority",
        "ViewMode",
        "BROWSE",
        "SELECT",
        "LogViewMode",
        "ALL_LOGS",
        "ONLY_USER",
        "ONLY_SYSTEM",
        "TimeDisplay",
        "LOCALTIME",
        "UTC",
        "MONOTONIC_TIMESTAMP",
        "FilterCriterium",
        "SYSTEMD_UNIT",
        "EXECUTABLE",
        "ServiceGrouping",
        "GROUP_SERVICE_TEMPLATES",
        "UNGROUP_SERVICE_TEMPLATES"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'timeDisplayChanged'
        QtMocHelpers::SignalData<void(BrowserApplication::TimeDisplay)>(5, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Signal 'filterCriteriumChanged'
        QtMocHelpers::SignalData<void(BrowserApplication::FilterCriterium)>(9, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 10, 11 },
        }}),
        // Signal 'viewModeChanged'
        QtMocHelpers::SignalData<void(BrowserApplication::ViewMode)>(12, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 13, 14 },
        }}),
        // Signal 'logViewModeChanged'
        QtMocHelpers::SignalData<void(BrowserApplication::LogViewMode)>(15, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 16, 14 },
        }}),
        // Signal 'serviceGroupingChanged'
        QtMocHelpers::SignalData<void(BrowserApplication::ServiceGrouping)>(17, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 18, 14 },
        }}),
        // Signal 'logPriorityChanged'
        QtMocHelpers::SignalData<void(quint32)>(19, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 20 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'timeDisplay'
        QtMocHelpers::PropertyData<BrowserApplication::TimeDisplay>(21, 0x80000000 | 7, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet | QMC::Final, 0),
        // property 'filterCriterium'
        QtMocHelpers::PropertyData<BrowserApplication::FilterCriterium>(22, 0x80000000 | 10, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet | QMC::Final, 1),
        // property 'viewMode'
        QtMocHelpers::PropertyData<BrowserApplication::ViewMode>(23, 0x80000000 | 13, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet | QMC::Final, 2),
        // property 'logViewMode'
        QtMocHelpers::PropertyData<BrowserApplication::LogViewMode>(24, 0x80000000 | 16, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet | QMC::Final, 3),
        // property 'serviceGrouping'
        QtMocHelpers::PropertyData<BrowserApplication::ServiceGrouping>(25, 0x80000000 | 18, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet | QMC::Final, 4),
        // property 'logPriority'
        QtMocHelpers::PropertyData<quint8>(26, QMetaType::UChar, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 5),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'ViewMode'
        QtMocHelpers::EnumData<enum ViewMode>(27, 27, QMC::EnumIsScoped).add({
            {   28, ViewMode::BROWSE },
            {   29, ViewMode::SELECT },
        }),
        // enum 'LogViewMode'
        QtMocHelpers::EnumData<enum LogViewMode>(30, 30, QMC::EnumIsScoped).add({
            {   31, LogViewMode::ALL_LOGS },
            {   32, LogViewMode::ONLY_USER },
            {   33, LogViewMode::ONLY_SYSTEM },
        }),
        // enum 'TimeDisplay'
        QtMocHelpers::EnumData<enum TimeDisplay>(34, 34, QMC::EnumIsScoped).add({
            {   35, TimeDisplay::LOCALTIME },
            {   36, TimeDisplay::UTC },
            {   37, TimeDisplay::MONOTONIC_TIMESTAMP },
        }),
        // enum 'FilterCriterium'
        QtMocHelpers::EnumData<enum FilterCriterium>(38, 38, QMC::EnumIsScoped).add({
            {   39, FilterCriterium::SYSTEMD_UNIT },
            {   40, FilterCriterium::EXECUTABLE },
        }),
        // enum 'ServiceGrouping'
        QtMocHelpers::EnumData<enum ServiceGrouping>(41, 41, QMC::EnumIsScoped).add({
            {   42, ServiceGrouping::GROUP_SERVICE_TEMPLATES },
            {   43, ServiceGrouping::UNGROUP_SERVICE_TEMPLATES },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<BrowserApplication, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject BrowserApplication::staticMetaObject = { {
    QMetaObject::SuperData::link<AbstractKirigamiApplication::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18BrowserApplicationE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18BrowserApplicationE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN18BrowserApplicationE_t>.metaTypes,
    nullptr
} };

void BrowserApplication::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<BrowserApplication *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->timeDisplayChanged((*reinterpret_cast<std::add_pointer_t<BrowserApplication::TimeDisplay>>(_a[1]))); break;
        case 1: _t->filterCriteriumChanged((*reinterpret_cast<std::add_pointer_t<BrowserApplication::FilterCriterium>>(_a[1]))); break;
        case 2: _t->viewModeChanged((*reinterpret_cast<std::add_pointer_t<BrowserApplication::ViewMode>>(_a[1]))); break;
        case 3: _t->logViewModeChanged((*reinterpret_cast<std::add_pointer_t<BrowserApplication::LogViewMode>>(_a[1]))); break;
        case 4: _t->serviceGroupingChanged((*reinterpret_cast<std::add_pointer_t<BrowserApplication::ServiceGrouping>>(_a[1]))); break;
        case 5: _t->logPriorityChanged((*reinterpret_cast<std::add_pointer_t<quint32>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (BrowserApplication::*)(BrowserApplication::TimeDisplay )>(_a, &BrowserApplication::timeDisplayChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (BrowserApplication::*)(BrowserApplication::FilterCriterium )>(_a, &BrowserApplication::filterCriteriumChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (BrowserApplication::*)(BrowserApplication::ViewMode )>(_a, &BrowserApplication::viewModeChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (BrowserApplication::*)(BrowserApplication::LogViewMode )>(_a, &BrowserApplication::logViewModeChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (BrowserApplication::*)(BrowserApplication::ServiceGrouping )>(_a, &BrowserApplication::serviceGroupingChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (BrowserApplication::*)(quint32 )>(_a, &BrowserApplication::logPriorityChanged, 5))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<BrowserApplication::TimeDisplay*>(_v) = _t->timeDisplay(); break;
        case 1: *reinterpret_cast<BrowserApplication::FilterCriterium*>(_v) = _t->filterCriterium(); break;
        case 2: *reinterpret_cast<BrowserApplication::ViewMode*>(_v) = _t->viewMode(); break;
        case 3: *reinterpret_cast<BrowserApplication::LogViewMode*>(_v) = _t->logViewMode(); break;
        case 4: *reinterpret_cast<BrowserApplication::ServiceGrouping*>(_v) = _t->serviceGrouping(); break;
        case 5: *reinterpret_cast<quint8*>(_v) = _t->logPriority(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setTimeDisplay(*reinterpret_cast<BrowserApplication::TimeDisplay*>(_v)); break;
        case 1: _t->setFilterCriterium(*reinterpret_cast<BrowserApplication::FilterCriterium*>(_v)); break;
        case 2: _t->setViewMode(*reinterpret_cast<BrowserApplication::ViewMode*>(_v)); break;
        case 3: _t->setLogViewMode(*reinterpret_cast<BrowserApplication::LogViewMode*>(_v)); break;
        case 4: _t->setServiceGrouping(*reinterpret_cast<BrowserApplication::ServiceGrouping*>(_v)); break;
        case 5: _t->setLogPriority(*reinterpret_cast<quint8*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *BrowserApplication::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *BrowserApplication::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18BrowserApplicationE_t>.strings))
        return static_cast<void*>(this);
    return AbstractKirigamiApplication::qt_metacast(_clname);
}

int BrowserApplication::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = AbstractKirigamiApplication::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 6;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    return _id;
}

// SIGNAL 0
void BrowserApplication::timeDisplayChanged(BrowserApplication::TimeDisplay _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void BrowserApplication::filterCriteriumChanged(BrowserApplication::FilterCriterium _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void BrowserApplication::viewModeChanged(BrowserApplication::ViewMode _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void BrowserApplication::logViewModeChanged(BrowserApplication::LogViewMode _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void BrowserApplication::serviceGroupingChanged(BrowserApplication::ServiceGrouping _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void BrowserApplication::logPriorityChanged(quint32 _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}
QT_WARNING_POP
