/****************************************************************************
** Meta object code from reading C++ file 'databaseprovider.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../kjournald-26.08.0/org/kde/kjournaldbrowser/databaseprovider.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'databaseprovider.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN16DatabaseProviderE_t {};
} // unnamed namespace

template <> constexpr inline auto DatabaseProvider::qt_create_metaobjectdata<qt_meta_tag_ZN16DatabaseProviderE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DatabaseProvider",
        "QML.Element",
        "auto",
        "QML.Singleton",
        "true",
        "journalChanged",
        "",
        "accessChanged",
        "localJournalPathChanged",
        "remoteJournalUrlChanged",
        "remoteJournalPortChanged",
        "currentJournalInfoTextChanged",
        "loadJournalFromLocalPath",
        "QUrl",
        "path",
        "loadSystemJournal",
        "loadJournalFromRemoteAddress",
        "url",
        "port",
        "access",
        "DatabaseProvider::DatabaseAccessLimit",
        "localJournalPath",
        "remoteJournalUrl",
        "remoteJournalPort",
        "currentJournalInfoText",
        "journalProvider",
        "IJournalProvider*",
        "DatabaseType",
        "FOLDER",
        "LOCAL_SYSTEM",
        "REMOTE",
        "DatabaseAccessLimit",
        "ALL",
        "CURRENT_USER"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'journalChanged'
        QtMocHelpers::SignalData<void()>(5, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'accessChanged'
        QtMocHelpers::SignalData<void()>(7, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'localJournalPathChanged'
        QtMocHelpers::SignalData<void()>(8, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'remoteJournalUrlChanged'
        QtMocHelpers::SignalData<void()>(9, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'remoteJournalPortChanged'
        QtMocHelpers::SignalData<void()>(10, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'currentJournalInfoTextChanged'
        QtMocHelpers::SignalData<void()>(11, 6, QMC::AccessPublic, QMetaType::Void),
        // Method 'loadJournalFromLocalPath'
        QtMocHelpers::MethodData<void(const QUrl &)>(12, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 13, 14 },
        }}),
        // Method 'loadSystemJournal'
        QtMocHelpers::MethodData<void()>(15, 6, QMC::AccessPublic, QMetaType::Void),
        // Method 'loadJournalFromRemoteAddress'
        QtMocHelpers::MethodData<void(const QString &, quint32)>(16, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 17 }, { QMetaType::UInt, 18 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'access'
        QtMocHelpers::PropertyData<DatabaseProvider::DatabaseAccessLimit>(19, 0x80000000 | 20, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet | QMC::Final, 1),
        // property 'localJournalPath'
        QtMocHelpers::PropertyData<QString>(21, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Final, 2),
        // property 'remoteJournalUrl'
        QtMocHelpers::PropertyData<QString>(22, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Final, 3),
        // property 'remoteJournalPort'
        QtMocHelpers::PropertyData<quint32>(23, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Final, 4),
        // property 'currentJournalInfoText'
        QtMocHelpers::PropertyData<QString>(24, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Final, 5),
        // property 'journalProvider'
        QtMocHelpers::PropertyData<IJournalProvider*>(25, 0x80000000 | 26, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Final, 0),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'DatabaseType'
        QtMocHelpers::EnumData<enum DatabaseType>(27, 27, QMC::EnumIsScoped).add({
            {   28, DatabaseType::FOLDER },
            {   29, DatabaseType::LOCAL_SYSTEM },
            {   30, DatabaseType::REMOTE },
        }),
        // enum 'DatabaseAccessLimit'
        QtMocHelpers::EnumData<enum DatabaseAccessLimit>(31, 31, QMC::EnumIsScoped).add({
            {   32, DatabaseAccessLimit::ALL },
            {   33, DatabaseAccessLimit::CURRENT_USER },
            {   29, DatabaseAccessLimit::LOCAL_SYSTEM },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<DatabaseProvider, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject DatabaseProvider::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16DatabaseProviderE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16DatabaseProviderE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN16DatabaseProviderE_t>.metaTypes,
    nullptr
} };

void DatabaseProvider::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DatabaseProvider *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->journalChanged(); break;
        case 1: _t->accessChanged(); break;
        case 2: _t->localJournalPathChanged(); break;
        case 3: _t->remoteJournalUrlChanged(); break;
        case 4: _t->remoteJournalPortChanged(); break;
        case 5: _t->currentJournalInfoTextChanged(); break;
        case 6: _t->loadJournalFromLocalPath((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 7: _t->loadSystemJournal(); break;
        case 8: _t->loadJournalFromRemoteAddress((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<quint32>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DatabaseProvider::*)()>(_a, &DatabaseProvider::journalChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DatabaseProvider::*)()>(_a, &DatabaseProvider::accessChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (DatabaseProvider::*)()>(_a, &DatabaseProvider::localJournalPathChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (DatabaseProvider::*)()>(_a, &DatabaseProvider::remoteJournalUrlChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (DatabaseProvider::*)()>(_a, &DatabaseProvider::remoteJournalPortChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (DatabaseProvider::*)()>(_a, &DatabaseProvider::currentJournalInfoTextChanged, 5))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 5:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< IJournalProvider* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<DatabaseProvider::DatabaseAccessLimit*>(_v) = _t->access(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->localJournalPath(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->remoteJournalUrl(); break;
        case 3: *reinterpret_cast<quint32*>(_v) = _t->remoteJournalPort(); break;
        case 4: *reinterpret_cast<QString*>(_v) = _t->currentJournalInfoText(); break;
        case 5: *reinterpret_cast<IJournalProvider**>(_v) = _t->journalProvider(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setAccess(*reinterpret_cast<DatabaseProvider::DatabaseAccessLimit*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *DatabaseProvider::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DatabaseProvider::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16DatabaseProviderE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int DatabaseProvider::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 9;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    return _id;
}

// SIGNAL 0
void DatabaseProvider::journalChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void DatabaseProvider::accessChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void DatabaseProvider::localJournalPathChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void DatabaseProvider::remoteJournalUrlChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void DatabaseProvider::remoteJournalPortChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void DatabaseProvider::currentJournalInfoTextChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}
QT_WARNING_POP
