/****************************************************************************
** Meta object code from reading C++ file 'filtercriteriamodel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../kjournald-26.08.0/org/kde/kjournald/filtercriteriamodel.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'filtercriteriamodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN19FilterCriteriaModelE_t {};
} // unnamed namespace

template <> constexpr inline auto FilterCriteriaModel::qt_create_metaobjectdata<qt_meta_tag_ZN19FilterCriteriaModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "FilterCriteriaModel",
        "QML.Element",
        "auto",
        "priorityFilterChanged",
        "",
        "priorityIndex",
        "priorityFilterUserChanged",
        "bootFilterChanged",
        "filter",
        "systemdUserUnitFilterChanged",
        "systemdSystemUnitFilterChanged",
        "exeFilterChanged",
        "kernelFilterChanged",
        "journalProviderChanged",
        "groupTemplatedSystemdUnitsChanged",
        "logViewModeChanged",
        "setData",
        "QModelIndex",
        "index",
        "QVariant",
        "value",
        "role",
        "journalProvider",
        "IJournalProvider*",
        "bootFilter",
        "priorityFilter",
        "systemdUserUnitFilter",
        "systemdSystemUnitFilter",
        "exeFilter",
        "kernelFilter",
        "enableSystemdUnitTemplateGrouping",
        "logViewMode",
        "LogViewMode",
        "Category",
        "TRANSPORT",
        "PRIORITY",
        "SYSTEMD_USER_UNIT",
        "SYSTEMD_SYSTEM_UNIT",
        "EXE",
        "Roles",
        "TEXT",
        "LONGTEXT",
        "SELECTED",
        "CATEGORY",
        "DATA",
        "HAS_CHILDREN",
        "ALL_LOGS",
        "ONLY_USER",
        "ONLY_SYSTEM"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'priorityFilterChanged'
        QtMocHelpers::SignalData<void(qint8)>(3, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::SChar, 5 },
        }}),
        // Signal 'priorityFilterUserChanged'
        QtMocHelpers::SignalData<void(qint8)>(6, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::SChar, 5 },
        }}),
        // Signal 'bootFilterChanged'
        QtMocHelpers::SignalData<void(QString)>(7, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 8 },
        }}),
        // Signal 'systemdUserUnitFilterChanged'
        QtMocHelpers::SignalData<void()>(9, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'systemdSystemUnitFilterChanged'
        QtMocHelpers::SignalData<void()>(10, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'exeFilterChanged'
        QtMocHelpers::SignalData<void()>(11, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'kernelFilterChanged'
        QtMocHelpers::SignalData<void()>(12, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'journalProviderChanged'
        QtMocHelpers::SignalData<void()>(13, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'groupTemplatedSystemdUnitsChanged'
        QtMocHelpers::SignalData<void()>(14, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'logViewModeChanged'
        QtMocHelpers::SignalData<void()>(15, 4, QMC::AccessPublic, QMetaType::Void),
        // Method 'setData'
        QtMocHelpers::MethodData<bool(const QModelIndex &, const QVariant &, int)>(16, 4, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 17, 18 }, { 0x80000000 | 19, 20 }, { QMetaType::Int, 21 },
        }}),
        // Method 'setData'
        QtMocHelpers::MethodData<bool(const QModelIndex &, const QVariant &)>(16, 4, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Bool, {{
            { 0x80000000 | 17, 18 }, { 0x80000000 | 19, 20 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'journalProvider'
        QtMocHelpers::PropertyData<IJournalProvider*>(22, 0x80000000 | 23, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet | QMC::Final, 7),
        // property 'bootFilter'
        QtMocHelpers::PropertyData<QString>(24, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::Resettable | QMC::StdCppSet | QMC::Final, 2),
        // property 'priorityFilter'
        QtMocHelpers::PropertyData<qint8>(25, QMetaType::SChar, QMC::DefaultPropertyFlags | QMC::Final, 0),
        // property 'systemdUserUnitFilter'
        QtMocHelpers::PropertyData<QStringList>(26, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Final, 3),
        // property 'systemdSystemUnitFilter'
        QtMocHelpers::PropertyData<QStringList>(27, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Final, 4),
        // property 'exeFilter'
        QtMocHelpers::PropertyData<QStringList>(28, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Final, 5),
        // property 'kernelFilter'
        QtMocHelpers::PropertyData<bool>(29, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Final, 6),
        // property 'enableSystemdUnitTemplateGrouping'
        QtMocHelpers::PropertyData<bool>(30, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::Final, 8),
        // property 'logViewMode'
        QtMocHelpers::PropertyData<enum LogViewMode>(31, 0x80000000 | 32, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet | QMC::Final, 9),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Category'
        QtMocHelpers::EnumData<enum Category>(33, 33, QMC::EnumFlags{}).add({
            {   34, Category::TRANSPORT },
            {   35, Category::PRIORITY },
            {   36, Category::SYSTEMD_USER_UNIT },
            {   37, Category::SYSTEMD_SYSTEM_UNIT },
            {   38, Category::EXE },
        }),
        // enum 'Roles'
        QtMocHelpers::EnumData<enum Roles>(39, 39, QMC::EnumFlags{}).add({
            {   40, Roles::TEXT },
            {   41, Roles::LONGTEXT },
            {   42, Roles::SELECTED },
            {   43, Roles::CATEGORY },
            {   44, Roles::DATA },
            {   45, Roles::HAS_CHILDREN },
        }),
        // enum 'LogViewMode'
        QtMocHelpers::EnumData<enum LogViewMode>(32, 32, QMC::EnumIsScoped).add({
            {   46, LogViewMode::ALL_LOGS },
            {   47, LogViewMode::ONLY_USER },
            {   48, LogViewMode::ONLY_SYSTEM },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<FilterCriteriaModel, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject FilterCriteriaModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QAbstractItemModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19FilterCriteriaModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19FilterCriteriaModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN19FilterCriteriaModelE_t>.metaTypes,
    nullptr
} };

void FilterCriteriaModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<FilterCriteriaModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->priorityFilterChanged((*reinterpret_cast<std::add_pointer_t<qint8>>(_a[1]))); break;
        case 1: _t->priorityFilterUserChanged((*reinterpret_cast<std::add_pointer_t<qint8>>(_a[1]))); break;
        case 2: _t->bootFilterChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 3: _t->systemdUserUnitFilterChanged(); break;
        case 4: _t->systemdSystemUnitFilterChanged(); break;
        case 5: _t->exeFilterChanged(); break;
        case 6: _t->kernelFilterChanged(); break;
        case 7: _t->journalProviderChanged(); break;
        case 8: _t->groupTemplatedSystemdUnitsChanged(); break;
        case 9: _t->logViewModeChanged(); break;
        case 10: { bool _r = _t->setData((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 11: { bool _r = _t->setData((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (FilterCriteriaModel::*)(qint8 )>(_a, &FilterCriteriaModel::priorityFilterChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (FilterCriteriaModel::*)(qint8 )>(_a, &FilterCriteriaModel::priorityFilterUserChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (FilterCriteriaModel::*)(QString )>(_a, &FilterCriteriaModel::bootFilterChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (FilterCriteriaModel::*)()>(_a, &FilterCriteriaModel::systemdUserUnitFilterChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (FilterCriteriaModel::*)()>(_a, &FilterCriteriaModel::systemdSystemUnitFilterChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (FilterCriteriaModel::*)()>(_a, &FilterCriteriaModel::exeFilterChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (FilterCriteriaModel::*)()>(_a, &FilterCriteriaModel::kernelFilterChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (FilterCriteriaModel::*)()>(_a, &FilterCriteriaModel::journalProviderChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (FilterCriteriaModel::*)()>(_a, &FilterCriteriaModel::groupTemplatedSystemdUnitsChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (FilterCriteriaModel::*)()>(_a, &FilterCriteriaModel::logViewModeChanged, 9))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< IJournalProvider* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<IJournalProvider**>(_v) = _t->journalProvider(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->bootFilter(); break;
        case 2: *reinterpret_cast<qint8*>(_v) = _t->priorityFilter(); break;
        case 3: *reinterpret_cast<QStringList*>(_v) = _t->systemdUserUnitFilter(); break;
        case 4: *reinterpret_cast<QStringList*>(_v) = _t->systemdSystemUnitFilter(); break;
        case 5: *reinterpret_cast<QStringList*>(_v) = _t->exeFilter(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->isKernelFilterEnabled(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->groupTemplatedSystemdUnits(); break;
        case 8: *reinterpret_cast<enum LogViewMode*>(_v) = _t->logViewMode(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setJournalProvider(*reinterpret_cast<IJournalProvider**>(_v)); break;
        case 1: _t->setBootFilter(*reinterpret_cast<QString*>(_v)); break;
        case 7: _t->setGroupTemplatedSystemdUnits(*reinterpret_cast<bool*>(_v)); break;
        case 8: _t->setLogViewMode(*reinterpret_cast<enum LogViewMode*>(_v)); break;
        default: break;
        }
    }
    if (_c == QMetaObject::ResetProperty) {
        switch (_id) {
        case 1: _t->resetBootFilter(); break;
        default: break;
        }
    }
}

const QMetaObject *FilterCriteriaModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *FilterCriteriaModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19FilterCriteriaModelE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "QQmlParserStatus"))
        return static_cast< QQmlParserStatus*>(this);
    if (!strcmp(_clname, "org.qt-project.Qt.QQmlParserStatus"))
        return static_cast< QQmlParserStatus*>(this);
    return QAbstractItemModel::qt_metacast(_clname);
}

int FilterCriteriaModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAbstractItemModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 12)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 12;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    return _id;
}

// SIGNAL 0
void FilterCriteriaModel::priorityFilterChanged(qint8 _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void FilterCriteriaModel::priorityFilterUserChanged(qint8 _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void FilterCriteriaModel::bootFilterChanged(QString _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void FilterCriteriaModel::systemdUserUnitFilterChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void FilterCriteriaModel::systemdSystemUnitFilterChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void FilterCriteriaModel::exeFilterChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void FilterCriteriaModel::kernelFilterChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void FilterCriteriaModel::journalProviderChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void FilterCriteriaModel::groupTemplatedSystemdUnitsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void FilterCriteriaModel::logViewModeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}
QT_WARNING_POP
