// This file was generated by ecm_qt_declare_logging_category(): DO NOT EDIT!

#include "kjournaldlib_log_filtertrace.h"


Q_LOGGING_CATEGORY(KJOURNALDLIB_FILTERTRACE, "kjournald.lib.general", QtInfoMsg)

