/****************************************************************************
** Meta object code from reading C++ file 'journaldhelper.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../kjournald-26.08.0/org/kde/kjournald/journaldhelper.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'journaldhelper.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN14JournaldHelperE_t {};
} // unnamed namespace

template <> constexpr inline auto JournaldHelper::qt_create_metaobjectdata<qt_meta_tag_ZN14JournaldHelperE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "JournaldHelper",
        "Field",
        "MESSAGE",
        "MESSAGE_ID",
        "PRIORITY",
        "CODE_FILE",
        "CODE_LINE",
        "CODE_FUNC",
        "_BOOT_ID",
        "_EXE",
        "_SYSTEMD_CGROUP",
        "_SYSTEMD_SLICE",
        "_SYSTEMD_UNIT",
        "_SYSTEMD_USER_UNIT",
        "_SYSTEMD_USER_SLICE",
        "_SYSTEMD_SESSION",
        "_SYSTEMD_OWNER_UID",
        "_TRANSPORT"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Field'
        QtMocHelpers::EnumData<enum Field>(1, 1, QMC::EnumIsScoped).add({
            {    2, Field::MESSAGE },
            {    3, Field::MESSAGE_ID },
            {    4, Field::PRIORITY },
            {    5, Field::CODE_FILE },
            {    6, Field::CODE_LINE },
            {    7, Field::CODE_FUNC },
            {    8, Field::_BOOT_ID },
            {    9, Field::_EXE },
            {   10, Field::_SYSTEMD_CGROUP },
            {   11, Field::_SYSTEMD_SLICE },
            {   12, Field::_SYSTEMD_UNIT },
            {   13, Field::_SYSTEMD_USER_UNIT },
            {   14, Field::_SYSTEMD_USER_SLICE },
            {   15, Field::_SYSTEMD_SESSION },
            {   16, Field::_SYSTEMD_OWNER_UID },
            {   17, Field::_TRANSPORT },
        }),
    };
    return QtMocHelpers::metaObjectData<JournaldHelper, qt_meta_tag_ZN14JournaldHelperE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject JournaldHelper::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14JournaldHelperE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14JournaldHelperE_t>.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14JournaldHelperE_t>.metaTypes,
    nullptr
} };

QT_WARNING_POP
