/****************************************************************************
** Generated QML type registration code
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <QtQml/qqml.h>
#include <QtQml/qqmlmoduleregistration.h>

#if __has_include(<bootmodel.h>)
#  include <bootmodel.h>
#endif
#if __has_include(<fieldfilterproxymodel.h>)
#  include <fieldfilterproxymodel.h>
#endif
#if __has_include(<filter.h>)
#  include <filter.h>
#endif
#if __has_include(<filtercriteriamodel.h>)
#  include <filtercriteriamodel.h>
#endif
#if __has_include(<flattenedfiltercriteriaproxymodel.h>)
#  include <flattenedfiltercriteriaproxymodel.h>
#endif
#if __has_include(<ijournalprovider.h>)
#  include <ijournalprovider.h>
#endif
#if __has_include(<journalduniquequerymodel.h>)
#  include <journalduniquequerymodel.h>
#endif
#if __has_include(<journaldviewmodel.h>)
#  include <journaldviewmodel.h>
#endif
#if __has_include(<logentry.h>)
#  include <logentry.h>
#endif


#if !defined(QT_STATIC)
#define Q_QMLTYPE_EXPORT Q_DECL_EXPORT
#else
#define Q_QMLTYPE_EXPORT
#endif
Q_QMLTYPE_EXPORT void qml_register_types_org_kde_kjournald()
{
    qmlRegisterModule("org.kde.kjournald", 254, 0);
    QT_WARNING_PUSH QT_WARNING_DISABLE_DEPRECATED
    qmlRegisterTypesAndRevisions<BootModel>("org.kde.kjournald", 254);
    qmlRegisterEnum<BootModel::Roles>("BootModel::Roles");
    qmlRegisterTypesAndRevisions<FieldFilterProxyModel>("org.kde.kjournald", 254);
    qmlRegisterTypesAndRevisions<Filter>("org.kde.kjournald", 254);
    qmlRegisterTypesAndRevisions<FilterCriteriaModel>("org.kde.kjournald", 254);
    qmlRegisterEnum<FilterCriteriaModel::Category>("FilterCriteriaModel::Category");
    qmlRegisterEnum<FilterCriteriaModel::Roles>("FilterCriteriaModel::Roles");
    qmlRegisterEnum<FilterCriteriaModel::LogViewMode>("FilterCriteriaModel::LogViewMode");
    qmlRegisterTypesAndRevisions<FlattenedFilterCriteriaProxyModel>("org.kde.kjournald", 254);
    qmlRegisterEnum<FlattenedFilterCriteriaProxyModel::Roles>("FlattenedFilterCriteriaProxyModel::Roles");
    qmlRegisterEnum<FlattenedFilterCriteriaProxyModel::DelgateType>("FlattenedFilterCriteriaProxyModel::DelgateType");
    qmlRegisterTypesAndRevisions<IJournalProvider>("org.kde.kjournald", 254);
    qmlRegisterTypesAndRevisions<JournaldUniqueQueryModel>("org.kde.kjournald", 254);
    qmlRegisterEnum<JournaldUniqueQueryModel::Roles>("JournaldUniqueQueryModel::Roles");
    qmlRegisterTypesAndRevisions<JournaldViewModel>("org.kde.kjournald", 254);
    qmlRegisterEnum<JournaldViewModel::Roles>("JournaldViewModel::Roles");
    qmlRegisterEnum<JournaldViewModel::Direction>("JournaldViewModel::Direction");
    qmlRegisterTypesAndRevisions<LogEntry>("org.kde.kjournald", 254);
    QMetaType::fromType<QAbstractItemModel *>().id();
    qmlRegisterEnum<QAbstractItemModel::LayoutChangeHint>("QAbstractItemModel::LayoutChangeHint");
    qmlRegisterEnum<QAbstractItemModel::CheckIndexOption>("QAbstractItemModel::CheckIndexOption");
    QMetaType::fromType<QAbstractListModel *>().id();
    QMetaType::fromType<QAbstractProxyModel *>().id();
    QMetaType::fromType<QSortFilterProxyModel *>().id();
    QT_WARNING_POP
    qmlRegisterModule("org.kde.kjournald", 254, 254);
}

static const QQmlModuleRegistration orgkdekjournaldRegistration("org.kde.kjournald", qml_register_types_org_kde_kjournald);
