/****************************************************************************
** Generated QML type registration code
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <QtQml/qqml.h>
#include <QtQml/qqmlmoduleregistration.h>

#if __has_include(<browserapplication.h>)
#  include <browserapplication.h>
#endif
#if __has_include(<clipboardproxy.h>)
#  include <clipboardproxy.h>
#endif
#if __has_include(<databaseprovider.h>)
#  include <databaseprovider.h>
#endif
#if __has_include(<formatter.h>)
#  include <formatter.h>
#endif
#if __has_include(<textsearch.h>)
#  include <textsearch.h>
#endif


#if !defined(QT_STATIC)
#define Q_QMLTYPE_EXPORT Q_DECL_EXPORT
#else
#define Q_QMLTYPE_EXPORT
#endif
Q_QMLTYPE_EXPORT void qml_register_types_org_kde_kjournaldbrowser()
{
    qmlRegisterModule("org.kde.kjournaldbrowser", 254, 0);
    QT_WARNING_PUSH QT_WARNING_DISABLE_DEPRECATED
    qmlRegisterTypesAndRevisions<BrowserApplication>("org.kde.kjournaldbrowser", 254);
    qmlRegisterEnum<BrowserApplication::ViewMode>("BrowserApplication::ViewMode");
    qmlRegisterEnum<BrowserApplication::LogViewMode>("BrowserApplication::LogViewMode");
    qmlRegisterEnum<BrowserApplication::TimeDisplay>("BrowserApplication::TimeDisplay");
    qmlRegisterEnum<BrowserApplication::FilterCriterium>("BrowserApplication::FilterCriterium");
    qmlRegisterEnum<BrowserApplication::ServiceGrouping>("BrowserApplication::ServiceGrouping");
    qmlRegisterTypesAndRevisions<ClipboardProxy>("org.kde.kjournaldbrowser", 254);
    qmlRegisterTypesAndRevisions<DatabaseProvider>("org.kde.kjournaldbrowser", 254);
    qmlRegisterEnum<DatabaseProvider::DatabaseType>("DatabaseProvider::DatabaseType");
    qmlRegisterEnum<DatabaseProvider::DatabaseAccessLimit>("DatabaseProvider::DatabaseAccessLimit");
    qmlRegisterTypesAndRevisions<Formatter>("org.kde.kjournaldbrowser", 254);
    qmlRegisterTypesAndRevisions<TextSearch>("org.kde.kjournaldbrowser", 254);
    QT_WARNING_POP
    qmlRegisterModule("org.kde.kjournaldbrowser", 254, 254);
}

static const QQmlModuleRegistration orgkdekjournaldbrowserRegistration("org.kde.kjournaldbrowser", qml_register_types_org_kde_kjournaldbrowser);
