// This file is autogenerated by CMake. Do not edit.

#include <QtCore/qtsymbolmacros.h>
#include <QtQml/qqmlextensionplugin.h>


QT_DECLARE_EXTERN_RESOURCE(qmlcache_kjournaldbrowser_backing)
QT_DECLARE_EXTERN_RESOURCE(qmake_org_kde_kjournaldbrowser)
QT_DECLARE_EXTERN_RESOURCE(kjournaldbrowser_backing_raw_qml_0)


QT_DECLARE_EXTERN_SYMBOL_VOID(qml_register_types_org_kde_kjournaldbrowser)

class org_kde_kjournaldbrowserPlugin : public QQmlEngineExtensionPlugin
{
    Q_OBJECT
    Q_PLUGIN_METADATA(IID QQmlEngineExtensionInterface_iid)

public:
    org_kde_kjournaldbrowserPlugin(QObject *parent = nullptr) : QQmlEngineExtensionPlugin(parent)
    {

QT_KEEP_SYMBOL(qml_register_types_org_kde_kjournaldbrowser)
QT_KEEP_RESOURCE(qmlcache_kjournaldbrowser_backing)
QT_KEEP_RESOURCE(qmake_org_kde_kjournaldbrowser)
QT_KEEP_RESOURCE(kjournaldbrowser_backing_raw_qml_0)
    }
};



#include "kjournaldbrowser_backingplugin_org_kde_kjournaldbrowserPlugin.moc"
