/****************************************************************************
** Meta object code from reading C++ file 'flattenedfiltercriteriaproxymodel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../kjournald-26.08.0/org/kde/kjournald/flattenedfiltercriteriaproxymodel.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'flattenedfiltercriteriaproxymodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN33FlattenedFilterCriteriaProxyModelE_t {};
} // unnamed namespace

template <> constexpr inline auto FlattenedFilterCriteriaProxyModel::qt_create_metaobjectdata<qt_meta_tag_ZN33FlattenedFilterCriteriaProxyModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "FlattenedFilterCriteriaProxyModel",
        "QML.Element",
        "auto",
        "sourceModelChanged",
        "",
        "handleSourceModelDataChanged",
        "QModelIndex",
        "topLeft",
        "bottomRight",
        "QList<int>",
        "roles",
        "handleSourceModelOnModelReset",
        "handleSourceModelOnModelAboutToBeReset",
        "sourceModel",
        "QAbstractItemModel*",
        "Roles",
        "TEXT",
        "LONGTEXT",
        "SELECTED",
        "INDENTATION",
        "EXPANDED",
        "EXPANDABLE",
        "TYPE",
        "COLOR",
        "DelgateType",
        "SECTION",
        "CHECKBOX",
        "RADIOBUTTON",
        "UNSELECT_OPTION",
        "FIRST_LEVEL"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'sourceModelChanged'
        QtMocHelpers::SignalData<void()>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'handleSourceModelDataChanged'
        QtMocHelpers::SlotData<void(const QModelIndex &, const QModelIndex &, const QVector<int> &)>(5, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 6, 7 }, { 0x80000000 | 6, 8 }, { 0x80000000 | 9, 10 },
        }}),
        // Slot 'handleSourceModelOnModelReset'
        QtMocHelpers::SlotData<void()>(11, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'handleSourceModelOnModelAboutToBeReset'
        QtMocHelpers::SlotData<void()>(12, 4, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'sourceModel'
        QtMocHelpers::PropertyData<QAbstractItemModel*>(13, 0x80000000 | 14, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Roles'
        QtMocHelpers::EnumData<enum Roles>(15, 15, QMC::EnumFlags{}).add({
            {   16, Roles::TEXT },
            {   17, Roles::LONGTEXT },
            {   18, Roles::SELECTED },
            {   19, Roles::INDENTATION },
            {   20, Roles::EXPANDED },
            {   21, Roles::EXPANDABLE },
            {   22, Roles::TYPE },
            {   23, Roles::COLOR },
        }),
        // enum 'DelgateType'
        QtMocHelpers::EnumData<enum DelgateType>(24, 24, QMC::EnumFlags{}).add({
            {   25, DelgateType::SECTION },
            {   26, DelgateType::CHECKBOX },
            {   27, DelgateType::RADIOBUTTON },
            {   28, DelgateType::UNSELECT_OPTION },
            {   29, DelgateType::FIRST_LEVEL },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<FlattenedFilterCriteriaProxyModel, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject FlattenedFilterCriteriaProxyModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QAbstractListModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN33FlattenedFilterCriteriaProxyModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN33FlattenedFilterCriteriaProxyModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN33FlattenedFilterCriteriaProxyModelE_t>.metaTypes,
    nullptr
} };

void FlattenedFilterCriteriaProxyModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<FlattenedFilterCriteriaProxyModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->sourceModelChanged(); break;
        case 1: _t->handleSourceModelDataChanged((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QList<int>>>(_a[3]))); break;
        case 2: _t->handleSourceModelOnModelReset(); break;
        case 3: _t->handleSourceModelOnModelAboutToBeReset(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 2:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<int> >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (FlattenedFilterCriteriaProxyModel::*)()>(_a, &FlattenedFilterCriteriaProxyModel::sourceModelChanged, 0))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QAbstractItemModel* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QAbstractItemModel**>(_v) = _t->sourceModel(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setSourceModel(*reinterpret_cast<QAbstractItemModel**>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *FlattenedFilterCriteriaProxyModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *FlattenedFilterCriteriaProxyModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN33FlattenedFilterCriteriaProxyModelE_t>.strings))
        return static_cast<void*>(this);
    return QAbstractListModel::qt_metacast(_clname);
}

int FlattenedFilterCriteriaProxyModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAbstractListModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void FlattenedFilterCriteriaProxyModel::sourceModelChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
QT_WARNING_POP
